Package: fixes
Type: Package
Title: Staggered DiD Tools: Event Studies and ATT Aggregation
Version: 0.11.2
Date: 2026-06-11
Authors@R: c(
    person(
      "Yosuke", "Abe",
      email = "yosuke.abe0507@gmail.com",
      role = c("aut", "cre")
    )
  )
Description: Provides tools for difference-in-differences (DiD) estimation and
    visualization with staggered adoption. Includes run_es() for event-study
    curves (dynamic effects by relative time) and calc_att() for aggregated
    ATT estimation (overall, by cohort, by calendar time). Supports multiple
    modern estimators: Callaway-Sant'Anna (2021), Sun-Abraham (2021),
    Borusyak-Jaravel-Spiess (2024), Wooldridge TWM, and Deb et al. FLEX.
Depends: R (>= 4.1.0)
Imports: dplyr, ggplot2, fixest, broom, tibble, rlang, Rcpp, scales
License: MIT + file LICENSE
Encoding: UTF-8
Suggests: knitr, rmarkdown, haven, testthat, plotly, tidyr, did,
        didimputation, modelsummary, tinytable, lpSolveAPI, Rglpk,
        TruncatedNormal, Matrix, pracma, HonestDiD
VignetteBuilder: knitr
URL: https://github.com/yo5uke/fixes, https://yo5uke.com/fixes/
BugReports: https://github.com/yo5uke/fixes/issues
Config/roxygen2/version: 8.0.0
Config/roxygen2/markdown: TRUE
LinkingTo: Rcpp, RcppArmadillo
NeedsCompilation: yes
Packaged: 2026-06-11 13:52:24 UTC; yo5uk
Author: Yosuke Abe [aut, cre]
Maintainer: Yosuke Abe <yosuke.abe0507@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-11 15:10:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-06-11 17:11:01 UTC; unix
Archs: fixes.so.dSYM
