# Generated by roxygen2: do not edit by hand

S3method(autoplot,es_result)
S3method(broom::glance,att_result)
S3method(broom::glance,did_result)
S3method(broom::tidy,att_result)
S3method(broom::tidy,did_result)
S3method(ggplot2::autoplot,att_gt_result)
S3method(ggplot2::autoplot,es_result)
S3method(ggplot2::autoplot,honest_result)
S3method(print,att_result)
S3method(print,did_result)
S3method(print,es_result)
S3method(print,honest_result)
S3method(print,sa_contamination_weights)
export(calc_att)
export(compute_contamination_weights)
export(honest_sensitivity)
export(plot_att_gt)
export(plot_contamination_weights)
export(plot_es)
export(plot_es_interactive)
export(plot_honest)
export(run_did)
export(run_es)
importFrom(Rcpp,sourceCpp)
importFrom(broom,tidy)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,dense_rank)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n_distinct)
importFrom(dplyr,ungroup)
importFrom(fixest,feols)
importFrom(ggplot2,aes)
importFrom(ggplot2,autoplot)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,theme_bw)
importFrom(rlang,.data)
importFrom(rlang,as_string)
importFrom(rlang,enexpr)
importFrom(rlang,expr_text)
importFrom(rlang,f_lhs)
importFrom(rlang,f_rhs)
importFrom(rlang,is_call)
importFrom(rlang,is_symbol)
importFrom(stats,as.formula)
importFrom(stats,nobs)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,vcov)
importFrom(utils,getFromNamespace)
useDynLib(fixes, .registration = TRUE)
