# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

compute_att_gt_cpp <- function(unit_id, time_id, outcome, cohort, cohorts, all_times, control_group, anticipation = 0L) {
    .Call(`_fixes_compute_att_gt_cpp`, unit_id, time_id, outcome, cohort, cohorts, all_times, control_group, anticipation)
}

